@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def roc(df, price="close", col="roc", n):
+def roc(df, n, price="close", col="roc"):
     """
     The Price Rate of Change (ROC) is a momentum-based technical indicator that measures the percentage change in price between the current price 
     and the price a certain number of periods ago. The ROC indicator is plotted against zero, 
