@@ -7,7 +7,7 @@ from voyant_indicators.overlapping_studies.wma import wma
 from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
-def stoch(df, high="high" ,low="low", price="close",col="stoch",n,ma_type,ma_n):
+def stoch(df, n,ma_type,ma_n, high="high" ,low="low", price="close",col="stoch"):
     """
     The Stochastic Oscillator is another well-known momentum indicator used in
     technical analysis. The idea behind this indicator is that the closing
