@@ -6,7 +6,7 @@ from voyant_indicators.overlapping_studies.wma import wma
 from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
-def stochf(df, high="high", low="low", close="close", fast_k_n, fast_d_n, fast_d_ma_type=0,col="stochf"):
+def stochf(df, fast_k_n, fast_d_n, high="high", low="low", close="close", fast_d_ma_type=0,col="stochf"):
     """
     The Stochastic Oscillator is another well-known momentum indicator used in
     technical analysis. The idea behind this indicator is that the closing
