@@ -1,5 +1,6 @@
-def ohlcv(df,col):
+def ohlcv(df,col,n):
 
 	df = df.copy()
 	df = df[['datetime',col]]
-	return df
\ No newline at end of file
+
+	return df.tail(n)
\ No newline at end of file
