@@ -5,7 +5,7 @@ from voyant_indicators.volume.ad import ad
 from voyant_indicators.trend.ema import ema
 
 
-def adosc(df, high="high", low="low", close="close", volume="volume", col="adsoc", fast_period, slow_period):
+def adosc(df, fast_period, slow_period, high="high", low="low", close="close", volume="volume", col="adsoc"):
     """
     Developed by Marc Chaikin, the Chaikin Oscillator measures the momentum of the Accumulation Distribution Line using the MACD formula. 
     (This makes it an indicator of an indicator.) The Chaikin Oscillator is the difference between the 3-day and 10-day EMAs 
